==> haskell-optional-args-1.0.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optional-args.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optional-args
version:              1.0.2
visibility:           public
id:                   optional-args-1.0.2-7gL5IauFL6SAQfRW5EHXXe
key:                  optional-args-1.0.2-7gL5IauFL6SAQfRW5EHXXe
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Optional function arguments
description:
    This library provides a type for specifying `Optional` function
    arguments

    Read the tutorial in "Data.Optional" to learn more

category:             Data
abi:                  35bd3f15b8fef48714bac69ab725c0a4
exposed:              True
exposed-modules:      Data.Optional
import-dirs:          /usr/lib/ghc-8.8.3/site-local/optional-args-1.0.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/optional-args-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/optional-args-1.0.2
hs-libraries:         HSoptional-args-1.0.2-7gL5IauFL6SAQfRW5EHXXe
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-optional-args/html/optional-args.haddock

haddock-html:         /usr/share/doc/haskell-optional-args/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optional-args-1.0.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optional-args.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optional-args
version:              1.0.2
visibility:           public
id:                   optional-args-1.0.2-8K9sEgOT794Lg3dgyVmkBl
key:                  optional-args-1.0.2-8K9sEgOT794Lg3dgyVmkBl
license:              BSD-3-Clause
copyright:            2015 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Optional function arguments
description:
    This library provides a type for specifying `Optional` function
    arguments

    Read the tutorial in "Data.Optional" to learn more

category:             Data
abi:                  317324bd6ea3c9e1ea2569f9118096fd
exposed:              True
exposed-modules:      Data.Optional
import-dirs:          /usr/lib/ghc-8.10.1/site-local/optional-args-1.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/optional-args-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/optional-args-1.0.2
hs-libraries:         HSoptional-args-1.0.2-8K9sEgOT794Lg3dgyVmkBl
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-optional-args/html/optional-args.haddock

haddock-html:         /usr/share/doc/haskell-optional-args/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
